Module error

Module error 

errors

Enums

Error
Error is an embly error

Constants

__WASI_E2BIG
Argument list too long.
__WASI_EACCES
Permission denied.
__WASI_EADDRINUSE
Address in use.
__WASI_EADDRNOTAVAIL
Address not available.
__WASI_EAFNOSUPPORT
Address family not supported.
__WASI_EAGAIN
Resource unavailable, or operation would block.
__WASI_EALREADY
Connection already in progress.
__WASI_EBADF
Bad file descriptor.
__WASI_EBADMSG
Bad message.
__WASI_EBUSY
Device or resource busy.
__WASI_ECANCELED
Operation canceled.
__WASI_ECHILD
No child processes.
__WASI_ECONNABORTED
Connection aborted.
__WASI_ECONNREFUSED
Connection refused.
__WASI_ECONNRESET
Connection reset.
__WASI_EDEADLK
Resource deadlock would occur.
__WASI_EDESTADDRREQ
Destination address required.
__WASI_EDOM
Mathematics argument out of domain of function.
__WASI_EDQUOT
Reserved. (Quota exceeded.)
__WASI_EEXIST
File exists.
__WASI_EFAULT
Bad address.
__WASI_EFBIG
File too large.
__WASI_EHOSTUNREACH
Host is unreachable.
__WASI_EIDRM
Identifier removed.
__WASI_EILSEQ
Illegal byte sequence.
__WASI_EINPROGRESS
Operation in progress.
__WASI_EINTR
Interrupted function.
__WASI_EINVAL
Invalid argument.
__WASI_EIO
I/O error.
__WASI_EISCONN
Socket is connected.
__WASI_EISDIR
Is a directory.
__WASI_ELOOP
Too many levels of symbolic links.
__WASI_EMFILE
File descriptor value too large.
__WASI_EMLINK
Too many links.
__WASI_EMSGSIZE
Message too large.
__WASI_EMULTIHOP
Reserved. (Multihop attempted.)
__WASI_ENAMETOOLONG
Filename too long.
__WASI_ENETDOWN
Network is down.
__WASI_ENETRESET
Connection aborted by network.
__WASI_ENETUNREACH
Network unreachable.
__WASI_ENFILE
Too many files open in system.
__WASI_ENOBUFS
No buffer space available.
__WASI_ENODEV
No such device.
__WASI_ENOENT
No such file or directory.
__WASI_ENOEXEC
Executable file format error.
__WASI_ENOLCK
No locks available.
__WASI_ENOLINK
Reserved. (Link has been severed.)
__WASI_ENOMEM
Not enough space.
__WASI_ENOMSG
No message of the desired type.
__WASI_ENOPROTOOPT
Protocol not available.
__WASI_ENOSPC
No space left on device.
__WASI_ENOSYS
Function not supported. (Always unsupported.)
__WASI_ENOTCAPABLE
Extension: Capabilities insufficient.
__WASI_ENOTCONN
The socket is not connected.
__WASI_ENOTDIR
Not a directory or a symbolic link to a directory.
__WASI_ENOTEMPTY
Directory not empty.
__WASI_ENOTRECOVERABLE
State not recoverable.
__WASI_ENOTSOCK
Not a socket.
__WASI_ENOTSUP
Not supported, or operation not supported on socket. (Transient unsupported.)
__WASI_ENOTTY
Inappropriate I/O control operation.
__WASI_ENXIO
No such device or address.
__WASI_EOVERFLOW
Value too large to be stored in data type.
__WASI_EOWNERDEAD
Previous owner died.
__WASI_EPERM
Operation not permitted.
__WASI_EPIPE
Broken pipe.
__WASI_EPROTO
Protocol error.
__WASI_EPROTONOSUPPORT
Protocol not supported.
__WASI_EPROTOTYPE
Protocol wrong type for socket.
__WASI_ERANGE
Result too large.
__WASI_EROFS
Read-only file system.
__WASI_ESPIPE
Invalid seek.
__WASI_ESRCH
No such process.
__WASI_ESTALE
Reserved. (Stale file handle.)
__WASI_ESUCCESS
No error occurred. System call completed successfully.
__WASI_ETIMEDOUT
Connection timed out.
__WASI_ETXTBSY
Text file busy.
__WASI_EXDEV
Cross-device link.

Functions

wasi_err_to_io_err
convert a u16 wasi error type to an io::Error

Type Aliases

Result
Result is the embly custom result type